@@ -181,7 +181,7 @@ class Tracks(Layer):
 
         self._track_colors: np.ndarray | None = None
         self._colormaps_dict = colormaps_dict or {}  # additional colormaps
-        self._color_by = color_by  # default color by ID
+        self._color_by = 'track_id'  # default color by ID
         self._colormap = colormap
 
         # use this to update shaders when the displayed dims change
@@ -201,6 +201,7 @@ class Tracks(Layer):
 
         # set the data, features, and graph
         self.data = data
+        self._color_by = color_by
         if properties is not None:
             self.properties = properties
         else:
@@ -463,7 +464,7 @@ class Tracks(Layer):
         """Set the track graph."""
         # Ignored type, because mypy can't handle different signatures
         # on getters and setters; see https://github.com/python/mypy/issues/3004
-        self._manager.graph = graph  # type: ignore[assignment]
+        self._manager.graph = graph
         self._manager.build_graph()
         self.events.rebuild_graph()
 
